@@ -114,6 +114,7 @@ import_file_ui <- function(id, title = TRUE) {
 #'  \code{"button"} (when user click on button) or
 #'  \code{"change"} (each time user select a dataset in the list).
 #' @param return_class Class of returned data: \code{data.frame}, \code{data.table} or \code{tbl_df} (tibble).
+#' @param reset A `reactive` function that when triggered resets the data.
 #'
 #' @export
 #'
@@ -130,7 +131,8 @@ import_file_ui <- function(id, title = TRUE) {
 import_file_server <- function(id,
                                btn_show_data = TRUE,
                                trigger_return = c("button", "change"),
-                               return_class = c("data.frame", "data.table", "tbl_df")) {
+                               return_class = c("data.frame", "data.table", "tbl_df"),
+                               reset = reactive(NULL)) {
 
   trigger_return <- match.arg(trigger_return)
 
@@ -140,6 +142,12 @@ import_file_server <- function(id,
     imported_rv <- reactiveValues(data = NULL, name = NULL)
     temporary_rv <- reactiveValues(data = NULL, name = NULL, status = NULL)
 
+    observeEvent(reset(), {
+      temporary_rv$data <- NULL
+      temporary_rv$name <- NULL
+      temporary_rv$status <- NULL
+    })
+
     output$container_confirm_btn <- renderUI({
       if (identical(trigger_return, "button")) {
         button_import()
@@ -175,13 +183,19 @@ import_file_server <- function(id,
           which = input$sheet,
           skip = input$skip_rows
         ), silent = TRUE)
-      } else {
+      } else if(is_sas(input$file$datapath)) {
         imported <- try(rio::import(
           file = input$file$datapath,
           skip = input$skip_rows,
-          dec = input$dec,
           encoding = input$encoding
         ), silent = TRUE)
+      }else{
+         imported <- try(rio::import(
+          file = input$file$datapath,
+          skip = input$skip_rows,
+          dec= input$dec,
+          encoding = input$encoding
+        ), silent = TRUE) 
       }
 
       if (inherits(imported, "try-error") || NROW(imported) < 1) {
@@ -257,3 +271,7 @@ is_excel <- function(path) {
   isTRUE(tools::file_ext(path) %in% c("xls", "xlsx"))
 }
 
+is_sas <- function(path) {
+  isTRUE(tools::file_ext(path) %in% c("sas7bdat"))
+}
+
